@@ -12,6 +12,9 @@
 #'
 #' @export
 #'
+#' @seealso \code{\link{create.project}}, \code{\link{load.project}},
+#'   \code{\link{get.project}}, \code{\link{cache.project}}
+#'
 #' @examples
 #' library('ProjectTemplate')
 #'
@@ -20,5 +23,5 @@
 #' show.project()}
 show.project <- function()
 {
-  print(project.info)
+  print(get.project())
 }
