@@ -6,6 +6,12 @@
 #' or one specific query against any set of tables may be executed to generate
 #' a data set.
 #'
+#' queries can support string interpolation to execute code snippets. This is used
+#' to create queries that depend on data from other sources. Code delimited is @@\{...\}
+#'
+#' Example: query: SELECT * FROM my_table WHERE id IN (@@\{paste(ids, collapse = ',')\}).
+#' Here ids is data previously loaded into ProjectTemplate
+#'
 #' Examples of the DCF format and settings used in a .sql file are shown
 #' below:
 #'
@@ -58,6 +64,32 @@
 #' dbname: sample_database
 #' query: SELECT * FROM sample_table
 #'
+#' Example 8
+#' type: oracle
+#' user: sample_user
+#' password: sample_password
+#' dbname: sample_database
+#' table: sample_table
+#'
+#' Example 9
+#' type: jdbc
+#' class: oracle.jdbc.OracleDriver
+#' classpath: /path/to/ojdbc5.jar (or set in CLASSPATH)
+#' user: scott
+#' password: tiger
+#' url: jdbc:oracle:thin:@@myhost:1521:orcl
+#' query: select * from emp
+#'
+#' Example 10
+#' type: heroku
+#' classpath: /path/to/jdbc4.jar (or set in CLASSPATH)
+#' user: scott
+#' password: tiger
+#' host: heroku.postgres.url
+#' port: 1234
+#' dbname: herokudb 
+#' query: select * from emp
+#'
 #' @param data.file The name of the data file to be read.
 #' @param filename The path to the data set to be loaded.
 #' @param variable.name The name to be assigned to in the global environment.
@@ -68,23 +100,35 @@
 #' library('ProjectTemplate')
 #'
 #' \dontrun{sql.reader('example.sql', 'data/example.sql', 'example')}
+#'
+#' @include require.package.R
 sql.reader <- function(data.file, filename, variable.name)
 {
-  database.info <- ProjectTemplate:::translate.dcf(filename)
+  database.info <- translate.dcf(filename)
 
-  if (! (database.info[['type']] %in% c('mysql', 'sqlite', 'odbc', 'postgres')))
+  if (! is.null(database.info[['connection']]))
   {
-    warning('Only databases reachable through RMySQL, RSQLite, RODBC or RPostgreSQL are currently supported.')
+    connection_filename <- paste("data/", database.info[['connection']],".sql-connection", sep="")
+    connection.info <- translate.dcf(connection_filename)
+
+    # Allow .sql to override options defined in .connection
+    database.info <- modifyList(connection.info, database.info) 
+  }
+
+  if (! (database.info[['type']] %in% c('mysql', 'sqlite', 'odbc', 'postgres', 'oracle', 'jdbc', 'heroku')))
+  {
+    warning('Only databases reachable through RMySQL, RSQLite, RODBC ROracle or RPostgreSQL are currently supported.')
     assign(variable.name,
            NULL,
-           envir = .GlobalEnv)
+           envir = .TargetEnv)
     return()
   }
 
   # Draft code for ODBC support.
   if (database.info[['type']] == 'odbc')
   {
-    library('RODBC')
+    require.package('RODBC')
+
     connection.string <- paste('DSN=', database.info[['dsn']], ';',
                                'UID=', database.info[['user']], ';',
                                'PWD=', database.info[['password']], ';',
@@ -95,13 +139,14 @@ sql.reader <- function(data.file, filename, variable.name)
     odbcClose(connection)
     assign(variable.name,
            results,
-           envir = .GlobalEnv)
+           envir = .TargetEnv)
     return()
   }
   
   if (database.info[['type']] == 'mysql')
   {
-    library('RMySQL')
+    require.package('RMySQL')
+
     mysql.driver <- dbDriver("MySQL")
     
     # Default value for 'port' in mysqlNewConnection is 0.
@@ -115,13 +160,15 @@ sql.reader <- function(data.file, filename, variable.name)
                             password = database.info[['password']],
                             host = database.info[['host']],
                             dbname = database.info[['dbname']],
-                            port = database.info[['port']],
+                            port = as.integer(database.info[['port']]),
                             unix.socket = database.info[['socket']])
+    dbGetQuery(connection, "SET NAMES 'utf8'") # Switch to utf-8 strings
   }
 
   if (database.info[['type']] == 'sqlite')
   {
-    library('RSQLite')
+    require.package('RSQLite')
+
     sqlite.driver <- dbDriver("SQLite")
 
     connection <- dbConnect(sqlite.driver,
@@ -130,7 +177,8 @@ sql.reader <- function(data.file, filename, variable.name)
 
   if (database.info[['type']] == 'postgres')
   {
-    library('RPostgreSQL')
+    require.package('RPostgreSQL')
+
     mysql.driver <- dbDriver("PostgreSQL")
 
     connection <- dbConnect(mysql.driver,
@@ -140,6 +188,65 @@ sql.reader <- function(data.file, filename, variable.name)
                             dbname = database.info[['dbname']])
   }
 
+  if (database.info[['type']] == 'oracle')
+  {
+    require.package('RMySQL')
+
+    oracle.driver <- dbDriver("Oracle")
+    
+    # Default value for 'port' in mysqlNewConnection is 0.
+    if (is.null(database.info[['port']]))
+    {
+      database.info[['port']] <- 0
+    }
+    
+    connection <- dbConnect(oracle.driver,
+                            user = database.info[['user']],
+                            password = database.info[['password']],
+                            dbname = database.info[['dbname']])
+  }
+
+  if (database.info[['type']] == 'jdbc')
+  {
+    require.package('RJDBC')
+
+    ident.quote <- NA
+    if('identquote' %in% names(database.info))
+       ident.quote <- database.info[['identquote']]
+    
+    if(is.null(database.info[['classpath']])) {
+      database.info[['classpath']] = ''
+    }
+
+    rjdbc.driver <- JDBC(database.info[['class']], database.info[['classpath']], ident.quote)
+    connection <- dbConnect(rjdbc.driver,
+                            database.info[['url']],
+                            user = database.info[['user']],
+                            password = database.info[['password']])
+  }
+
+  if (database.info[['type']] == 'heroku')
+  {
+    require.package('RJDBC')
+    
+    if(is.null(database.info[['classpath']])) {
+      database.info[['classpath']] <- ''
+  }
+
+    database.info[['class']] <- 'org.postgresql.Driver'
+    
+    database.info[['url']] <- paste('jdbc:postgresql://', database.info[['host']], 
+        ':', database.info[['port']], 
+        '/', database.info[['dbname']], 
+        '?ssl=true&sslfactory=org.postgresql.ssl.NonValidatingFactory', sep = '')
+    
+    rjdbc.driver <- JDBC(database.info[['class']], database.info[['classpath']])
+    connection <- dbConnect(rjdbc.driver,
+                            database.info[['url']],
+                            user = database.info[['user']],
+                            password = database.info[['password']])
+  }
+
   # Added support for queries.
   # User should specify either a table name or a query to execute, but not both.
   table <- database.info[['table']]
@@ -172,9 +279,9 @@ sql.reader <- function(data.file, filename, variable.name)
                                  table,
                                  row.names = NULL)
     
-      assign(ProjectTemplate:::clean.variable.name(table),
+      assign(clean.variable.name(table),
              data.parcel,
-             envir = .GlobalEnv)
+             envir = .TargetEnv)
     }
   }
   
@@ -190,7 +297,7 @@ sql.reader <- function(data.file, filename, variable.name)
       
       assign(variable.name,
              data.parcel,
-             envir = .GlobalEnv)
+             envir = .TargetEnv)
     }
     else
     {
@@ -201,14 +308,19 @@ sql.reader <- function(data.file, filename, variable.name)
 
   if (! is.null(query))
   {
+    if (length(grep('\\@\\{.*\\}', query)) != 0) {
+      # Do string interpolation
+      require.package('GetoptLong')
+      query <- qq(query)
+    }
     data.parcel <- try(dbGetQuery(connection, query))
     err <- dbGetException(connection)
     
-    if (class(data.parcel) == 'data.frame' && err$errorNum == 0)
+    if (class(data.parcel) == 'data.frame' && (length(err) == 0 || err$errorNum == 0))
     {
       assign(variable.name,
              data.parcel,
-             envir = .GlobalEnv)
+             envir = .TargetEnv)
     }
     else
     {
@@ -232,7 +344,7 @@ sql.reader <- function(data.file, filename, variable.name)
   {
     assign(variable.name,
            NULL,
-           envir = .GlobalEnv)
+           envir = .TargetEnv)
     return()
   }
 
